local gr	= love.graphics

function love.load()
	local split	= require 'splita'
	path			= love.filesystem.getRealDirectory( 'main.lua' )..'/'
	image			= gr.newImage( mount(path..'pic.jpg' ) )
	wd, ht		= fit( image, 3, 2 )	-- size suitable for 6 images to be displayed
	love.window.setMode( 3*wd, 2*ht, { borderless = true } )
	gr.setBackgroundColor( 0.27, 0.25, 0.25 )
	gr.setLineWidth( 2 )
	setFontSize( 20 )
	red	= split.create( image, {1,0,0,1}, wd, ht )
	green	= split.create( image, {0,1,0,1}, wd, ht )
	blue	= split.create( image, {0,0,1,1}, wd, ht )

	--mix	= split.create( image, {1,1,0,0}, wd, ht )
	--saveCanvas( mix, path )
	--saveCanvas( split.create( image, {0,0,1}, 2*wd, 2*ht ), path, 'secondOption' )
	--saveCanvas( mix, path, 'newName' )	-- 'newName' replaces default name = 'mix.png'
	--clr = { red = {1,0,0,1}, green = {0,1,0,1}, blue = {0,0,1,1} }
	--for i,j in pairs( clr ) do _G[i] = split.create( image, j, wd, ht ) end
	gr.setBackgroundColor(.5,.5,.5)
	ang = 0
	end

function love.update( dt )
	ang = ang+dt
	end

function love.draw()
	if showgrid then grid( 80, 60 ) end
	gr.setColor( 1, 1, 1, 1 )
	gr.print( 'Color Separation', 90, 30 )
	gr.print( 'Original Image =>', wd/2-105, 140 )
	gr.print( '"p" key to add grid pattern',10,ht-60)
	gr.print( '"r,g,b" keys to save splits',10,ht-30)
	gr.draw( image, wd, 0, 0, wd/image:getWidth(), ht/image:getHeight() )
		gr.rectangle( 'line', wd, 0, wd-1, ht-2 )
	gr.draw( red, 0, ht )
		gr.rectangle( 'line', 0, ht, wd-1, ht-2 )
	gr.draw( green, wd, ht )
		gr.rectangle( 'line', wd, ht, wd-1, ht-2 )
	gr.draw( blue,	2*wd,	ht )
		gr.rectangle( 'line', 2*wd, ht, wd-1, ht-2 )
	--gr.draw( mix, 2*wd, 0 )
	cx,cy,cs=orbit(wd/2,100,130,10,ang)
	if cs>0 then
		gr.setColor(1,1,0)
		gr.circle('fill',wd/2,100,30)
		gr.setColor(0,1,0)
		gr.circle('fill',cx,cy,10)
		else gr.setColor(0,.8,0)
		gr.circle('fill',cx,cy,10)
		gr.setColor(1,1,0)
		gr.circle('fill',wd/2,100,30)
		end
	end

function love.keypressed( key )
	if key == 'escape'	then love.event.quit() 	end
	if key == 'p'			then showgrid = not showgrid end
	if key == 'r'			then saveCanvas( red, path, 'Red Colors') end
	if key == 'g'			then saveCanvas( green, path, 'Green Colors') end
	if key == 'b'			then saveCanvas( blue, path, 'Blue Colors') end
	end

fit = function( image, nx, ny )
	local dtw, dth	= love.window.getDesktopDimensions(  )
	local iw,  ih	= image:getWidth(), image:getHeight()
	local sz			=  math.min( dtw / (nx*iw), dth / (ny*ih) )
	return sz*iw, sz*ih
	end

setFontSize = function( size )
	gr.setFont( gr.newFont( size ) )
	end

saveCanvas = function( can, path, name )
	local id = can:newImageData( )
	id:encode( 'png', mount( path..name..'.png' ) )
	end

mount = function( name )
	local ffi	= require( 'ffi' )
	local lv		= ffi.load( 'love' )
	ffi.cdef[[ int PHYSFS_mount(const char *newDir, const char *mountPoint, int appendToPath); ]];
	ffi.cdef[[ int PHYSFS_setWriteDir(const char *newDir); ]]
	local file	= name:match( "^.+/(.+)$" )			-- filename
	local path	= string.sub( name, 1, -(#file+1) )	-- path without filename
	lv.PHYSFS_setWriteDir( path )
	lv.PHYSFS_mount( path, nil, 0 )
	return file
	end

grid = function( nx, ny )	-- background to confirm transparent
	gr.setColor( 0.4, 0.4, 0.4, 1 )
	local wd,ht  = love.window.getMode( )
	local sx,sy = wd/nx,ht/ny
	for x = 0, nx do gr.line( sx*x, 0, sx*x,ht ) end
	for y = 0, ny do gr.line( 0, sy*y, wd,sy*y ) end
	end

orbit = function( x, y, rx, ry, an )
	local sin, cos = math.sin, math.cos
	local cs = sin( an )
	return  rx * cos( an ) + x, ry * sin( an ) + y, cs
	end