-- splita.lua - a library permiting splitting images into single-color images
local gr = love.graphics
local split  = {
	shader = gr.newShader(
		[[
		extern vec4 channel;
		extern float lim;				// image specific magic number
		int alpha;						// which color to display 0-2
		vec4 effect( vec4 global_color, Image texture, vec2 tc, vec2 pc )
			{
			if ( channel[0] > 0.0 ) { alpha = 0; }
				else if ( channel[1] > 0.0 ) { alpha = 1; }
				else if ( channel[2] > 0.0 ) { alpha = 2; }
				else { alpha = 0; }		// default to red
			vec4 pixel = Texel( texture, vec2( tc ) ) * channel;
			if ( pixel[ alpha ] > lim ) { pixel.a = 1.0; } else { pixel.a = 0.0; }
			return pixel;
			}
		]] )
		}
	split.create = function( im, color, w, h, lim )		-- seperate color channels
		local w,h,lim = w or 300, h or 300, lim or 0.25	-- magic number
		local can = gr.newCanvas( w, h )
		split.shader:send( 'channel', color )	-- color should have 0 or 1 values only
		split.shader:send( 'lim', lim )
		gr.setCanvas( can )
			gr.setShader( split.shader )
				gr.draw( im, 0, 0, 0, w/im:getWidth(), h/im:getHeight()  )
				gr.setShader()
			gr.setCanvas()
		return can
		end

return split
